@@ -5,16 +5,36 @@ knitr::opts_chunk$set(
 )
 
 ## ----setup, include=FALSE-----------------------------------------------------
-library(rscc)
+library("rscc")
+
+## ---- eval=FALSE--------------------------------------------------------------
+#  files <- ... # get file names from somehere, e.g. list.files()
+#  prgs  <- sourcecode(files, title=basename(files))
+#  docs  <- documents(prgs, type="names")
+#  sim   <- similarities(docs)  # you may use alternatively tfidf()
+#  dfsim <- matrix2dataframe(sim)
+#  head(dfsim, n=25)
+#  browse(prgs, dfsim, n=6)     # creates and opens a HTML file
+
+## ---- eval=FALSE--------------------------------------------------------------
+#  files <- ... # get file names from somehere, e.g. list.files()
+#  # load all expressions with at least `minlines` lines
+#  prgs  <- sourcecode(files, title=basename(files), minlines=0)
+#  docs  <- documents(prgs, type="names")
+#  sim   <- similarities(docs)  # you may use alternatively tfidf()
+#  sim   <- same_file(sim)      # do not compare expressions within one file
+#  dfsim <- matrix2dataframe(sim)
+#  head(dfsim, n=25)
+#  browse(prgs, dfsim, n=6)     # creates and opens a HTML file
 
 ## -----------------------------------------------------------------------------
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE)
+prgs  <- sourcecode(files, title=basename(files))
 names(prgs)
 
 ## -----------------------------------------------------------------------------
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE, minlines=3, silent=TRUE)
+prgs  <- sourcecode(files, title=basename(files), minlines=3, silent=TRUE)
 names(prgs)
 
 ## -----------------------------------------------------------------------------
@@ -30,7 +50,7 @@ setdiff(all.names(prgs[[1]]), all.vars(prgs[[1]])) # type="f"
 
 ## -----------------------------------------------------------------------------
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE, silent=TRUE)
+prgs  <- sourcecode(files, title=basename(files), silent=TRUE)
 docs  <- documents(prgs)
 similarities(docs)[1:8,1:8]
 
@@ -45,19 +65,19 @@ similarities(docs)[1:8,1:8]
 
 ## -----------------------------------------------------------------------------
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE, silent=TRUE)
+prgs  <- sourcecode(files, title=basename(files), silent=TRUE)
 docs  <- documents(prgs)
 similarities(docs, coeff="m")[1:8,1:8]
 
 ## -----------------------------------------------------------------------------
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE, silent=TRUE)
+prgs  <- sourcecode(files, title=basename(files), silent=TRUE)
 docs  <- documents(prgs)
 tfidf(docs)[1:8,1:8]
 
 ## -----------------------------------------------------------------------------
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE, silent=TRUE)
+prgs  <- sourcecode(files, title=basename(files), silent=TRUE)
 docs  <- documents(prgs)
 simm  <- similarities(docs, coeff="m")
 simdf <- matrix2dataframe(simm)
@@ -69,7 +89,7 @@ stripchart(simdf[,3], "jitter", pch=19, xlab=names(simdf)[3])
 ## -----------------------------------------------------------------------------
 library("igraph")
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE, silent=TRUE)
+prgs  <- sourcecode(files, title=basename(files), silent=TRUE)
 docs  <- documents(prgs, type="n", minlen=3)
 simm  <- similarities(docs)
 graph <- as_igraph(simm, diag=FALSE)
@@ -80,7 +100,7 @@ box()
 
 ## -----------------------------------------------------------------------------
 files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-prgs  <- sourcecode(files, basename=TRUE, silent=TRUE, minlines=1)
+prgs  <- sourcecode(files, title=basename(files), silent=TRUE, minlines=1)
 docs  <- documents(prgs)
 simm  <- similarities(docs)
 simm[1:3,1:3]
@@ -89,7 +109,7 @@ simm[1:3,1:3]
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  files <- list.files(system.file("examples", package="rscc"), "*.R$", full.names = TRUE)
-#  prgs  <- sourcecode(files, basename=TRUE, silent=TRUE)
+#  prgs  <- sourcecode(files, title=basename(files), silent=TRUE)
 #  docs  <- documents(prgs, type="n", minlen=3)
 #  simdf <- matrix2dataframe(similarities(docs))
 #  if (interactive()) browse(prgs, simdf, simdf[,3]>0.4)
